RnBeads.data: RnBeads Annotation Tables
Description
RnBeads uses sets of annotation tables and mappings (from regions to sites) for each of the supported genomes. The
structures for one assembly are stored in a separate dedicated annotation package. The following annotation packages
are available in Bioconductor:
- RnBeads.hg19
- for
"hg19"
- RnBeads.mm10
- for
"mm10"
- RnBeads.mm9
- for
"mm9"
- RnBeads.rn5
- for
"rn5"
Format
list of four elements - "regions", "sites", "controls" and "mappings".
These elements are described below.
"regions"list of NULLs; the names of the elements correspond to the built-in
region annotation tables. Once the default annotations are loaded, the attribute "builtin" is
a logical vector storing, for each region annotation, whether it is the default (built-in) or
custom. "sites"list of NULLs; the names of the elements correspond to the site and
probe annotation tables. "controls"list of NULLs; the names of the elements correspond to the control
probe annotation tables. The attribute "sites" is a character vector pointing to the
site annotation that encompasses the respective control probes. "mappings"list of NULLs; the names of the elements correspond to the built-in
region annotation tables.