read.single.bed(file, chr.col = 1L, start.col = 2L, end.col = 3L, strand.col = 6L, mean.meth.col = 7L, coverage.col = 8L, c.col = NA, t.col = NA, is.epp.style = FALSE, coord.shift = 0L, ffread = FALSE, context = "cg", ...)"chrom", "start",
"end", "methylated_count/total_count", "meth_score_scaled_0_1000" and
"strand" in this order). Setting this to TRUE overwrites all other parameters except
file, and also neglects ....
@param coord.shift An integer specifying the coordinate adjustment applied to the start and end coordinates.
@param ffread Use ff package functionality
@param context prefix for the output rownames
@param ... further arguments to read.table or read.table.ffdf @details Missing columns should be assigned with NA. In case mean.meth.col is absent at least coverage.col
and one of c.col or t.col should be specified.
@return a data.frame or ff.data.frame object with DNA methylation and coverage information. The row names are formed by the following convension:
context\.read.delim(file,...)[,chr.col]\.read.delim(file,...)[,start.col]\.read.delim(file,...)[,strand.col].
@author Pavlo Lutsik @export