output directory. If not existing, it will be created. otherwise files in that directory are overwritten.
reg.type
region type to be converted
names.quant.meth
should the names of the bed regions contain information on the methylation level.
If TRUE the following format is applied: meth_percent
covg(rnb.set) is not NULL
add.track.line
Add a track line to the bed file to enable browsers like IGV to display the data better
verbose
More detailed logger output
Value
(invisibly) a summary list containing information on the conversion step.
elements are filenames (a table containing information on which sample has been written to what filename)
and assembly (a string indicating the assembly used by rnb.set).
Details
Details on bed can be found in the UCSC Genome Browser
documentation. Each methylation site is an entry in the resulting bed file. The Score column corresponds
to a site's methylation value in the interval [0,1].