dir.reports
Directory that contains HTML reports generated by RnBeads modules. If this directory
does not exist, is a regular file, is inaccessible, or does not contain any recognizable
HTML report files, this function does not generate an HTML index file and produces an error
or a warning message.
fname
One-element character vector specifying the name of the index file to be generated.
See the Details section for restrictions on the name. The file will be created in
dir.reports. If such a file already exists, it will be overwritten.