rnb.set.annotation to accept the region format as output by annotation(rnb.set).
Additionally, CpG statistics are added to the annotation.
rnb.set.annotation.and.cpg.stats(type, regions, description = NULL, assembly = "hg19")rnb.set.annotationrnb.set.annotation with the exception that
the genomic location columns should be specified using upper case first lettersTRUE if an existing annotation was replaced and FALSE otherwise.
rnb.set.annotation